/***********************************************************************
*
* screen.h - Screen header.
*
* Changes:
*   05/29/03   DGP   Original.
*
***********************************************************************/

extern void screenposition (int, int, int);
extern void clearline (int);
extern void cleartoendline (int);
extern void clearscreen (int);
extern void cleartoendscreen (int);
extern void screenattribute (int, int);

